@@ -85,7 +85,14 @@ class MeterSphereParser(object):
                         body = json.loads(mode_body)
                     except Exception as e:
                         body = mode_body
-                if isinstance(body, dict):
+                elif item.get("body") and isinstance(item["body"], dict):
+                    body = item["body"]
+                    if request["headers"].get('Content-Type', '').find('json') < 0:
+                        mode_body = ''
+                        for k, v in body.items():
+                            mode_body += '{}={}&'.format(k, v)
+                        body = mode_body[:-1]
+                if isinstance(body, dict) or request["headers"].get('Content-Type', '').find('json') >= 0:
                     request["json"] = body
                 else:
                     request["data"] = body
